/*
 * Copyright 2013 Zakhar Prykhoda
 *
 *    midao.org
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package org.midao.core.processor;

import org.midao.core.handlers.model.ProcessedInput;

import java.util.Map;

/**
 * Query Input Processor description.
 * This processor is used by {@link org.midao.core.handlers.input.InputHandler} during processing of
 * input SQL and input parameters
 */
public interface QueryInputProcessor {

    /**
     * Processes original SQL and params and returns ProcessedInput object with parsed SQL and
     * ordered map of parameters/values
     *
     * @param originalSql original SQL
     * @param params input parameters
     * @return processed SQL and list of parameters(and their values) in ProcessedInput class
     */
	public ProcessedInput processInput(String originalSql, Map<String, Object> params);

    /**
     * Checks if SQL string contains unnamed ("?") parameters
     *
     * @param originalSql original SQL
     * @return true - if original SQL contains unnamed ("?") parameters
     */
	public boolean hasUnnamedParameters(String originalSql);
}
